devicesinlan - Turulomio

# NAME

devicesinlan: Busca todos los dispositivos de tu LAN. Después, puedes establecer alias a tus dispositivos conocidos para detectar dispositivos extraños en tu red.

# SYNOPSIS

devicesinlan [-h] [--version] [--method {PingArp,ScapyArping,Scapy}] [--interface INTERFACE | --add | --remove | --list | --load LOAD | --save SAVE | --reset] [--debug DEBUG]

# DESCRIPCIÓN

Si lanzas DevicesInLan sin parámetros se ejecuta un asistente.

Además puedes usar uno de estos parámetros.

--interface

Escanea la red del interfaz pasado como parámetro y lista los dispositivos detectados.

Si un dispositivo no es conocido, se mostrará en rojo. Los dispositivos verdes son dispositivos confiables.

--add

Permite añadir un dispositivo conocido desde consola.

--remove

Permite borrar un dispositivo conocido desde consola.

--list

Muestra todos los dispositivos conocidos de la base de datos desde consola.

--load

Carga una lista de dispositivos conocidos en formato xml.

--save

Graba la lista de dispositivos conocidos a un fichero xml.

--debug

Devuelve información de depurado al ejecutar DevicesInLAN. Está desactivado por defecto

Este parámetro puede tomar estas opciones: CRITICAL, ERROR, WARNING, INFO, DEBUG.

--reset

Borra todos los dispositivos conocidos.

# MÉTODOS DE ESCANEADO

DevicesInLan puede utilizar varios métodos para buscar dispositivos. Solo necesita agregar --method en modo consola.

PingArp

Intenta realizar una conexión de socket con cualquier dispositivo en la lan. Luego busca con el comando 'arp' la información mac

El métoo PingArp es usado por defecto en las versiones de windows y linux.

Scapy

Usa Scapy para crear una peticion ARP y capturar su respuesta por cada ip en la subred, para conseguir la información de las MAC.

Este método se puede utilizar en versiones de Windows y Linux, pero debe ejecutarse con rol de administrador.

Además, necesita instalar 'npcap' para ejecutarlo en Windows.

ScapyArping

Utiliza la función arping de Scapy para crear una solicitud ARP y capturar su respuesta para cada ip en la subred para obtener información de macs.

Este método se puede utilizar en versiones de Windows y Linux, pero debe ejecutarse con rol de administrador.

Además, necesita instalar 'npcap' para ejecutarlo en Windows.

# EJEMPLOS

devicesinlan

Comando por defecto Usa el método PingArp.

devicesinlan --method ScapyArping

Usa el método ScapyArping.

Created with libmangenerator at 2025-12-28